# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/devices/generic/MemoryStateCollection.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.devices.generic.MemoryState_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/devices/generic/MemoryStateCollection.proto',
  package='rst.devices.generic',
  serialized_pb='\n/rst/devices/generic/MemoryStateCollection.proto\x12\x13rst.devices.generic\x1a%rst/devices/generic/MemoryState.proto\"J\n\x15MemoryStateCollection\x12\x31\n\x07\x65lement\x18\x01 \x03(\x0b\x32 .rst.devices.generic.MemoryStateB\x1b\x42\x19MemoryStateCollectionType')




_MEMORYSTATECOLLECTION = _descriptor.Descriptor(
  name='MemoryStateCollection',
  full_name='rst.devices.generic.MemoryStateCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='element', full_name='rst.devices.generic.MemoryStateCollection.element', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=111,
  serialized_end=185,
)

_MEMORYSTATECOLLECTION.fields_by_name['element'].message_type = rst.devices.generic.MemoryState_pb2._MEMORYSTATE
DESCRIPTOR.message_types_by_name['MemoryStateCollection'] = _MEMORYSTATECOLLECTION

class MemoryStateCollection(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _MEMORYSTATECOLLECTION

  # @@protoc_insertion_point(class_scope:rst.devices.generic.MemoryStateCollection)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\031MemoryStateCollectionType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/vision/Faces.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.vision.Face_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/vision/Faces.proto',
  package='rst.vision',
  serialized_pb='\n\x16rst/vision/Faces.proto\x12\nrst.vision\x1a\x15rst/vision/Face.proto\"G\n\x05\x46\x61\x63\x65s\x12\x1f\n\x05\x66\x61\x63\x65s\x18\x01 \x03(\x0b\x32\x10.rst.vision.Face\x12\r\n\x05width\x18\x02 \x02(\r\x12\x0e\n\x06height\x18\x03 \x02(\rB\x0b\x42\tFacesType')




_FACES = _descriptor.Descriptor(
  name='Faces',
  full_name='rst.vision.Faces',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='faces', full_name='rst.vision.Faces.faces', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='width', full_name='rst.vision.Faces.width', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='height', full_name='rst.vision.Faces.height', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=61,
  serialized_end=132,
)

_FACES.fields_by_name['faces'].message_type = rst.vision.Face_pb2._FACE
DESCRIPTOR.message_types_by_name['Faces'] = _FACES

class Faces(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _FACES

  # @@protoc_insertion_point(class_scope:rst.vision.Faces)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\tFacesType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/calendar/Todo.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.calendar.DateTime_pb2
import rst.calendar.Entry_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/calendar/Todo.proto',
  package='rst.calendar',
  serialized_pb='\n\x17rst/calendar/Todo.proto\x12\x0crst.calendar\x1a\x1brst/calendar/DateTime.proto\x1a\x18rst/calendar/Entry.proto\"\xb3\x02\n\x04Todo\x12\"\n\x05\x65ntry\x18\x01 \x01(\x0b\x32\x13.rst.calendar.Entry\x12-\n\rcompleted_utc\x18\x02 \x01(\x0b\x32\x16.rst.calendar.DateTime\x12\x12\n\x07percent\x18\x03 \x01(\r:\x01\x30\x12@\n\x0btodo_status\x18\x04 \x01(\x0e\x32\x1d.rst.calendar.Todo.TodoStatus:\x0cNEEDS_ACTION\x12#\n\x03\x64ue\x18\x05 \x01(\x0b\x32\x16.rst.calendar.DateTime\x12\x10\n\x08\x64uration\x18\x06 \x01(\x12\"K\n\nTodoStatus\x12\x10\n\x0cNEEDS_ACTION\x10\x01\x12\r\n\tCOMPLETED\x10\x02\x12\x0e\n\nIN_PROCESS\x10\x03\x12\x0c\n\x08\x43\x41NCELED\x10\x04\x42\nB\x08TodoType')



_TODO_TODOSTATUS = _descriptor.EnumDescriptor(
  name='TodoStatus',
  full_name='rst.calendar.Todo.TodoStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NEEDS_ACTION', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMPLETED', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IN_PROCESS', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANCELED', index=3, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=329,
  serialized_end=404,
)


_TODO = _descriptor.Descriptor(
  name='Todo',
  full_name='rst.calendar.Todo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entry', full_name='rst.calendar.Todo.entry', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='completed_utc', full_name='rst.calendar.Todo.completed_utc', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='percent', full_name='rst.calendar.Todo.percent', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='todo_status', full_name='rst.calendar.Todo.todo_status', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='due', full_name='rst.calendar.Todo.due', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='duration', full_name='rst.calendar.Todo.duration', index=5,
      number=6, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TODO_TODOSTATUS,
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=97,
  serialized_end=404,
)

_TODO.fields_by_name['entry'].message_type = rst.calendar.Entry_pb2._ENTRY
_TODO.fields_by_name['completed_utc'].message_type = rst.calendar.DateTime_pb2._DATETIME
_TODO.fields_by_name['todo_status'].enum_type = _TODO_TODOSTATUS
_TODO.fields_by_name['due'].message_type = rst.calendar.DateTime_pb2._DATETIME
_TODO_TODOSTATUS.containing_type = _TODO;
DESCRIPTOR.message_types_by_name['Todo'] = _TODO

class Todo(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TODO

  # @@protoc_insertion_point(class_scope:rst.calendar.Todo)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\010TodoType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/dialog/SpeechHypothesis.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.timing.Interval_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/dialog/SpeechHypothesis.proto',
  package='rst.dialog',
  serialized_pb='\n!rst/dialog/SpeechHypothesis.proto\x12\nrst.dialog\x1a\x19rst/timing/Interval.proto\"\xd7\x01\n\x10SpeechHypothesis\x12\x30\n\x05words\x18\x01 \x03(\x0b\x32!.rst.dialog.SpeechHypothesis.Word\x12\x12\n\nconfidence\x18\x02 \x01(\x02\x12\'\n\ttimestamp\x18\x03 \x01(\x0b\x32\x14.rst.timing.Interval\x12\x14\n\x0cgrammar_tree\x18\x04 \x01(\t\x1a>\n\x04Word\x12\x0c\n\x04word\x18\x01 \x02(\t\x12(\n\ntimestamps\x18\x02 \x01(\x0b\x32\x14.rst.timing.IntervalB\x16\x42\x14SpeechHypothesisType')




_SPEECHHYPOTHESIS_WORD = _descriptor.Descriptor(
  name='Word',
  full_name='rst.dialog.SpeechHypothesis.Word',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='word', full_name='rst.dialog.SpeechHypothesis.Word.word', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamps', full_name='rst.dialog.SpeechHypothesis.Word.timestamps', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=230,
  serialized_end=292,
)

_SPEECHHYPOTHESIS = _descriptor.Descriptor(
  name='SpeechHypothesis',
  full_name='rst.dialog.SpeechHypothesis',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='words', full_name='rst.dialog.SpeechHypothesis.words', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='confidence', full_name='rst.dialog.SpeechHypothesis.confidence', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='rst.dialog.SpeechHypothesis.timestamp', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='grammar_tree', full_name='rst.dialog.SpeechHypothesis.grammar_tree', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_SPEECHHYPOTHESIS_WORD, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=77,
  serialized_end=292,
)

_SPEECHHYPOTHESIS_WORD.fields_by_name['timestamps'].message_type = rst.timing.Interval_pb2._INTERVAL
_SPEECHHYPOTHESIS_WORD.containing_type = _SPEECHHYPOTHESIS;
_SPEECHHYPOTHESIS.fields_by_name['words'].message_type = _SPEECHHYPOTHESIS_WORD
_SPEECHHYPOTHESIS.fields_by_name['timestamp'].message_type = rst.timing.Interval_pb2._INTERVAL
DESCRIPTOR.message_types_by_name['SpeechHypothesis'] = _SPEECHHYPOTHESIS

class SpeechHypothesis(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType

  class Word(_message.Message):
    __metaclass__ = _reflection.GeneratedProtocolMessageType
    DESCRIPTOR = _SPEECHHYPOTHESIS_WORD

    # @@protoc_insertion_point(class_scope:rst.dialog.SpeechHypothesis.Word)
  DESCRIPTOR = _SPEECHHYPOTHESIS

  # @@protoc_insertion_point(class_scope:rst.dialog.SpeechHypothesis)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\024SpeechHypothesisType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/calendar/CalendarComponents.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.calendar.TimeZone_pb2
import rst.calendar.Event_pb2
import rst.calendar.Todo_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/calendar/CalendarComponents.proto',
  package='rst.calendar',
  serialized_pb='\n%rst/calendar/CalendarComponents.proto\x12\x0crst.calendar\x1a\x1brst/calendar/TimeZone.proto\x1a\x18rst/calendar/Event.proto\x1a\x17rst/calendar/Todo.proto\"\x87\x01\n\x12\x43\x61lendarComponents\x12)\n\ttimezones\x18\x01 \x03(\x0b\x32\x16.rst.calendar.TimeZone\x12#\n\x06\x65vents\x18\x02 \x03(\x0b\x32\x13.rst.calendar.Event\x12!\n\x05todos\x18\x03 \x03(\x0b\x32\x12.rst.calendar.TodoB\x18\x42\x16\x43\x61lendarComponentsType')




_CALENDARCOMPONENTS = _descriptor.Descriptor(
  name='CalendarComponents',
  full_name='rst.calendar.CalendarComponents',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timezones', full_name='rst.calendar.CalendarComponents.timezones', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='events', full_name='rst.calendar.CalendarComponents.events', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='todos', full_name='rst.calendar.CalendarComponents.todos', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=136,
  serialized_end=271,
)

_CALENDARCOMPONENTS.fields_by_name['timezones'].message_type = rst.calendar.TimeZone_pb2._TIMEZONE
_CALENDARCOMPONENTS.fields_by_name['events'].message_type = rst.calendar.Event_pb2._EVENT
_CALENDARCOMPONENTS.fields_by_name['todos'].message_type = rst.calendar.Todo_pb2._TODO
DESCRIPTOR.message_types_by_name['CalendarComponents'] = _CALENDARCOMPONENTS

class CalendarComponents(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _CALENDARCOMPONENTS

  # @@protoc_insertion_point(class_scope:rst.calendar.CalendarComponents)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\026CalendarComponentsType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/navigation/Path.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.geometry.Pose_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/navigation/Path.proto',
  package='rst.navigation',
  serialized_pb='\n\x19rst/navigation/Path.proto\x12\x0erst.navigation\x1a\x17rst/geometry/Pose.proto\")\n\x04Path\x12!\n\x05poses\x18\x01 \x03(\x0b\x32\x12.rst.geometry.PoseB\nB\x08PathType')




_PATH = _descriptor.Descriptor(
  name='Path',
  full_name='rst.navigation.Path',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='poses', full_name='rst.navigation.Path.poses', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=70,
  serialized_end=111,
)

_PATH.fields_by_name['poses'].message_type = rst.geometry.Pose_pb2._POSE
DESCRIPTOR.message_types_by_name['Path'] = _PATH

class Path(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _PATH

  # @@protoc_insertion_point(class_scope:rst.navigation.Path)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\010PathType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/navigation/OccupancyGrid2DIntCollection.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.navigation.OccupancyGrid2DInt_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/navigation/OccupancyGrid2DIntCollection.proto',
  package='rst.navigation',
  serialized_pb='\n1rst/navigation/OccupancyGrid2DIntCollection.proto\x12\x0erst.navigation\x1a\'rst/navigation/OccupancyGrid2DInt.proto\"S\n\x1cOccupancyGrid2DIntCollection\x12\x33\n\x07\x65lement\x18\x01 \x03(\x0b\x32\".rst.navigation.OccupancyGrid2DIntB\"B OccupancyGrid2DIntCollectionType')




_OCCUPANCYGRID2DINTCOLLECTION = _descriptor.Descriptor(
  name='OccupancyGrid2DIntCollection',
  full_name='rst.navigation.OccupancyGrid2DIntCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='element', full_name='rst.navigation.OccupancyGrid2DIntCollection.element', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=110,
  serialized_end=193,
)

_OCCUPANCYGRID2DINTCOLLECTION.fields_by_name['element'].message_type = rst.navigation.OccupancyGrid2DInt_pb2._OCCUPANCYGRID2DINT
DESCRIPTOR.message_types_by_name['OccupancyGrid2DIntCollection'] = _OCCUPANCYGRID2DINTCOLLECTION

class OccupancyGrid2DIntCollection(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _OCCUPANCYGRID2DINTCOLLECTION

  # @@protoc_insertion_point(class_scope:rst.navigation.OccupancyGrid2DIntCollection)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B OccupancyGrid2DIntCollectionType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/navigation/PlatformCapabilities.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/navigation/PlatformCapabilities.proto',
  package='rst.navigation',
  serialized_pb='\n)rst/navigation/PlatformCapabilities.proto\x12\x0erst.navigation\"e\n\x14PlatformCapabilities\x12\x14\n\x0cmax_velocity\x18\x01 \x01(\x02\x12\x18\n\x10max_acceleration\x18\x02 \x01(\x02\x12\x1d\n\x15has_fine_localization\x18\x03 \x01(\x08\x42\x1a\x42\x18PlatformCapabilitiesType')




_PLATFORMCAPABILITIES = _descriptor.Descriptor(
  name='PlatformCapabilities',
  full_name='rst.navigation.PlatformCapabilities',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_velocity', full_name='rst.navigation.PlatformCapabilities.max_velocity', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_acceleration', full_name='rst.navigation.PlatformCapabilities.max_acceleration', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='has_fine_localization', full_name='rst.navigation.PlatformCapabilities.has_fine_localization', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=61,
  serialized_end=162,
)

DESCRIPTOR.message_types_by_name['PlatformCapabilities'] = _PLATFORMCAPABILITIES

class PlatformCapabilities(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _PLATFORMCAPABILITIES

  # @@protoc_insertion_point(class_scope:rst.navigation.PlatformCapabilities)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\030PlatformCapabilitiesType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/classification/ClassifiedRegion3D.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.geometry.BoundingBox3DFloat_pb2
import rst.classification.ClassificationResult_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/classification/ClassifiedRegion3D.proto',
  package='rst.classification',
  serialized_pb='\n+rst/classification/ClassifiedRegion3D.proto\x12\x12rst.classification\x1a%rst/geometry/BoundingBox3DFloat.proto\x1a-rst/classification/ClassificationResult.proto\"\x80\x01\n\x12\x43lassifiedRegion3D\x12\x30\n\x06region\x18\x01 \x01(\x0b\x32 .rst.geometry.BoundingBox3DFloat\x12\x38\n\x06result\x18\x02 \x01(\x0b\x32(.rst.classification.ClassificationResultB\x18\x42\x16\x43lassifiedRegion3DType')




_CLASSIFIEDREGION3D = _descriptor.Descriptor(
  name='ClassifiedRegion3D',
  full_name='rst.classification.ClassifiedRegion3D',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='region', full_name='rst.classification.ClassifiedRegion3D.region', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='result', full_name='rst.classification.ClassifiedRegion3D.result', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=154,
  serialized_end=282,
)

_CLASSIFIEDREGION3D.fields_by_name['region'].message_type = rst.geometry.BoundingBox3DFloat_pb2._BOUNDINGBOX3DFLOAT
_CLASSIFIEDREGION3D.fields_by_name['result'].message_type = rst.classification.ClassificationResult_pb2._CLASSIFICATIONRESULT
DESCRIPTOR.message_types_by_name['ClassifiedRegion3D'] = _CLASSIFIEDREGION3D

class ClassifiedRegion3D(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _CLASSIFIEDREGION3D

  # @@protoc_insertion_point(class_scope:rst.classification.ClassifiedRegion3D)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\026ClassifiedRegion3DType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/geometry/Pose.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.geometry.Translation_pb2
import rst.geometry.Rotation_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/geometry/Pose.proto',
  package='rst.geometry',
  serialized_pb='\n\x17rst/geometry/Pose.proto\x12\x0crst.geometry\x1a\x1erst/geometry/Translation.proto\x1a\x1brst/geometry/Rotation.proto\"`\n\x04Pose\x12.\n\x0btranslation\x18\x01 \x02(\x0b\x32\x19.rst.geometry.Translation\x12(\n\x08rotation\x18\x02 \x02(\x0b\x32\x16.rst.geometry.RotationB\nB\x08PoseType')




_POSE = _descriptor.Descriptor(
  name='Pose',
  full_name='rst.geometry.Pose',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='translation', full_name='rst.geometry.Pose.translation', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rotation', full_name='rst.geometry.Pose.rotation', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=102,
  serialized_end=198,
)

_POSE.fields_by_name['translation'].message_type = rst.geometry.Translation_pb2._TRANSLATION
_POSE.fields_by_name['rotation'].message_type = rst.geometry.Rotation_pb2._ROTATION
DESCRIPTOR.message_types_by_name['Pose'] = _POSE

class Pose(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _POSE

  # @@protoc_insertion_point(class_scope:rst.geometry.Pose)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\010PoseType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/kinematics/JointAccelerations.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/kinematics/JointAccelerations.proto',
  package='rst.kinematics',
  serialized_pb='\n\'rst/kinematics/JointAccelerations.proto\x12\x0erst.kinematics\"/\n\x12JointAccelerations\x12\x19\n\raccelerations\x18\x01 \x03(\x02\x42\x02\x10\x01\x42\x18\x42\x16JointAccelerationsType')




_JOINTACCELERATIONS = _descriptor.Descriptor(
  name='JointAccelerations',
  full_name='rst.kinematics.JointAccelerations',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='accelerations', full_name='rst.kinematics.JointAccelerations.accelerations', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), '\020\001')),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=59,
  serialized_end=106,
)

DESCRIPTOR.message_types_by_name['JointAccelerations'] = _JOINTACCELERATIONS

class JointAccelerations(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _JOINTACCELERATIONS

  # @@protoc_insertion_point(class_scope:rst.kinematics.JointAccelerations)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\026JointAccelerationsType')
_JOINTACCELERATIONS.fields_by_name['accelerations'].has_options = True
_JOINTACCELERATIONS.fields_by_name['accelerations']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), '\020\001')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/kinematics/SpatialAccelerations.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.kinematics.LinearAccelerations_pb2
import rst.kinematics.AngularAccelerations_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/kinematics/SpatialAccelerations.proto',
  package='rst.kinematics',
  serialized_pb='\n)rst/kinematics/SpatialAccelerations.proto\x12\x0erst.kinematics\x1a(rst/kinematics/LinearAccelerations.proto\x1a)rst/kinematics/AngularAccelerations.proto\"\x82\x01\n\x14SpatialAccelerations\x12\x33\n\x06linear\x18\x01 \x02(\x0b\x32#.rst.kinematics.LinearAccelerations\x12\x35\n\x07\x61ngular\x18\x02 \x02(\x0b\x32$.rst.kinematics.AngularAccelerationsB\x1a\x42\x18SpatialAccelerationsType')




_SPATIALACCELERATIONS = _descriptor.Descriptor(
  name='SpatialAccelerations',
  full_name='rst.kinematics.SpatialAccelerations',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='linear', full_name='rst.kinematics.SpatialAccelerations.linear', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='angular', full_name='rst.kinematics.SpatialAccelerations.angular', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=147,
  serialized_end=277,
)

_SPATIALACCELERATIONS.fields_by_name['linear'].message_type = rst.kinematics.LinearAccelerations_pb2._LINEARACCELERATIONS
_SPATIALACCELERATIONS.fields_by_name['angular'].message_type = rst.kinematics.AngularAccelerations_pb2._ANGULARACCELERATIONS
DESCRIPTOR.message_types_by_name['SpatialAccelerations'] = _SPATIALACCELERATIONS

class SpatialAccelerations(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _SPATIALACCELERATIONS

  # @@protoc_insertion_point(class_scope:rst.kinematics.SpatialAccelerations)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\030SpatialAccelerationsType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/geometry/PointPairCollection.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.geometry.PointPair_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/geometry/PointPairCollection.proto',
  package='rst.geometry',
  serialized_pb='\n&rst/geometry/PointPairCollection.proto\x12\x0crst.geometry\x1a\x1crst/geometry/PointPair.proto\"?\n\x13PointPairCollection\x12(\n\x07\x65lement\x18\x01 \x03(\x0b\x32\x17.rst.geometry.PointPairB\x19\x42\x17PointPairCollectionType')




_POINTPAIRCOLLECTION = _descriptor.Descriptor(
  name='PointPairCollection',
  full_name='rst.geometry.PointPairCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='element', full_name='rst.geometry.PointPairCollection.element', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=86,
  serialized_end=149,
)

_POINTPAIRCOLLECTION.fields_by_name['element'].message_type = rst.geometry.PointPair_pb2._POINTPAIR
DESCRIPTOR.message_types_by_name['PointPairCollection'] = _POINTPAIRCOLLECTION

class PointPairCollection(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _POINTPAIRCOLLECTION

  # @@protoc_insertion_point(class_scope:rst.geometry.PointPairCollection)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\027PointPairCollectionType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/geometry/Shape3DFloat.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.geometry.BoundingBox3DFloat_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/geometry/Shape3DFloat.proto',
  package='rst.geometry',
  serialized_pb='\n\x1frst/geometry/Shape3DFloat.proto\x12\x0crst.geometry\x1a%rst/geometry/BoundingBox3DFloat.proto\"=\n\x0cShape3DFloat\x12-\n\x03\x62ox\x18\x01 \x03(\x0b\x32 .rst.geometry.BoundingBox3DFloatB\x12\x42\x10Shape3DFloatType')




_SHAPE3DFLOAT = _descriptor.Descriptor(
  name='Shape3DFloat',
  full_name='rst.geometry.Shape3DFloat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='box', full_name='rst.geometry.Shape3DFloat.box', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=88,
  serialized_end=149,
)

_SHAPE3DFLOAT.fields_by_name['box'].message_type = rst.geometry.BoundingBox3DFloat_pb2._BOUNDINGBOX3DFLOAT
DESCRIPTOR.message_types_by_name['Shape3DFloat'] = _SHAPE3DFLOAT

class Shape3DFloat(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _SHAPE3DFLOAT

  # @@protoc_insertion_point(class_scope:rst.geometry.Shape3DFloat)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\020Shape3DFloatType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/stochastics/MixtureOfGaussian1D.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.stochastics.Gaussian1D_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/stochastics/MixtureOfGaussian1D.proto',
  package='rst.stochastics',
  serialized_pb='\n)rst/stochastics/MixtureOfGaussian1D.proto\x12\x0frst.stochastics\x1a rst/stochastics/Gaussian1D.proto\"\xd4\x01\n\x13MixtureOfGaussian1D\x12L\n\ncomponents\x18\x01 \x03(\x0b\x32\x38.rst.stochastics.MixtureOfGaussian1D.GaussianComponent1D\x1ao\n\x13GaussianComponent1D\x12-\n\x08gaussian\x18\x01 \x02(\x0b\x32\x1b.rst.stochastics.Gaussian1D\x12\x0e\n\x06weight\x18\x02 \x02(\x02\x12\x19\n\x11probability_state\x18\x03 \x02(\x02\x42\x19\x42\x17MixtureOfGaussian1DType')




_MIXTUREOFGAUSSIAN1D_GAUSSIANCOMPONENT1D = _descriptor.Descriptor(
  name='GaussianComponent1D',
  full_name='rst.stochastics.MixtureOfGaussian1D.GaussianComponent1D',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gaussian', full_name='rst.stochastics.MixtureOfGaussian1D.GaussianComponent1D.gaussian', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='weight', full_name='rst.stochastics.MixtureOfGaussian1D.GaussianComponent1D.weight', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='probability_state', full_name='rst.stochastics.MixtureOfGaussian1D.GaussianComponent1D.probability_state', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=198,
  serialized_end=309,
)

_MIXTUREOFGAUSSIAN1D = _descriptor.Descriptor(
  name='MixtureOfGaussian1D',
  full_name='rst.stochastics.MixtureOfGaussian1D',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='components', full_name='rst.stochastics.MixtureOfGaussian1D.components', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_MIXTUREOFGAUSSIAN1D_GAUSSIANCOMPONENT1D, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=97,
  serialized_end=309,
)

_MIXTUREOFGAUSSIAN1D_GAUSSIANCOMPONENT1D.fields_by_name['gaussian'].message_type = rst.stochastics.Gaussian1D_pb2._GAUSSIAN1D
_MIXTUREOFGAUSSIAN1D_GAUSSIANCOMPONENT1D.containing_type = _MIXTUREOFGAUSSIAN1D;
_MIXTUREOFGAUSSIAN1D.fields_by_name['components'].message_type = _MIXTUREOFGAUSSIAN1D_GAUSSIANCOMPONENT1D
DESCRIPTOR.message_types_by_name['MixtureOfGaussian1D'] = _MIXTUREOFGAUSSIAN1D

class MixtureOfGaussian1D(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType

  class GaussianComponent1D(_message.Message):
    __metaclass__ = _reflection.GeneratedProtocolMessageType
    DESCRIPTOR = _MIXTUREOFGAUSSIAN1D_GAUSSIANCOMPONENT1D

    # @@protoc_insertion_point(class_scope:rst.stochastics.MixtureOfGaussian1D.GaussianComponent1D)
  DESCRIPTOR = _MIXTUREOFGAUSSIAN1D

  # @@protoc_insertion_point(class_scope:rst.stochastics.MixtureOfGaussian1D)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\027MixtureOfGaussian1DType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/devices/generic/UserState.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/devices/generic/UserState.proto',
  package='rst.devices.generic',
  serialized_pb='\n#rst/devices/generic/UserState.proto\x12\x13rst.devices.generic\"Q\n\tUserState\x12\x17\n\x0flogged_in_users\x18\x01 \x01(\r\x12\x16\n\x0elogin_sessions\x18\x02 \x01(\r\x12\x13\n\x0blogin_hosts\x18\x03 \x01(\rB\x0f\x42\rUserStateType')




_USERSTATE = _descriptor.Descriptor(
  name='UserState',
  full_name='rst.devices.generic.UserState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='logged_in_users', full_name='rst.devices.generic.UserState.logged_in_users', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='login_sessions', full_name='rst.devices.generic.UserState.login_sessions', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='login_hosts', full_name='rst.devices.generic.UserState.login_hosts', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=60,
  serialized_end=141,
)

DESCRIPTOR.message_types_by_name['UserState'] = _USERSTATE

class UserState(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _USERSTATE

  # @@protoc_insertion_point(class_scope:rst.devices.generic.UserState)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\rUserStateType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/generic/Dictionary.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.generic.KeyValuePair_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/generic/Dictionary.proto',
  package='rst.generic',
  serialized_pb='\n\x1crst/generic/Dictionary.proto\x12\x0brst.generic\x1a\x1erst/generic/KeyValuePair.proto\"8\n\nDictionary\x12*\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x19.rst.generic.KeyValuePairB\x10\x42\x0e\x44ictionaryType')




_DICTIONARY = _descriptor.Descriptor(
  name='Dictionary',
  full_name='rst.generic.Dictionary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='rst.generic.Dictionary.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=77,
  serialized_end=133,
)

_DICTIONARY.fields_by_name['entries'].message_type = rst.generic.KeyValuePair_pb2._KEYVALUEPAIR
DESCRIPTOR.message_types_by_name['Dictionary'] = _DICTIONARY

class Dictionary(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _DICTIONARY

  # @@protoc_insertion_point(class_scope:rst.generic.Dictionary)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\016DictionaryType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/kinematics/Posture3DFloat.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.geometry.Rotation_pb2
import rst.geometry.Translation_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/kinematics/Posture3DFloat.proto',
  package='rst.kinematics',
  serialized_pb='\n#rst/kinematics/Posture3DFloat.proto\x12\x0erst.kinematics\x1a\x1brst/geometry/Rotation.proto\x1a\x1erst/geometry/Translation.proto\"u\n\x0ePosture3DFloat\x12+\n\x08position\x18\x02 \x03(\x0b\x32\x19.rst.geometry.Translation\x12(\n\x08rotation\x18\x03 \x03(\x0b\x32\x16.rst.geometry.Rotation\x12\x0c\n\x04name\x18\x04 \x03(\x0c\x42\x14\x42\x12Posture3DFloatType')




_POSTURE3DFLOAT = _descriptor.Descriptor(
  name='Posture3DFloat',
  full_name='rst.kinematics.Posture3DFloat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='position', full_name='rst.kinematics.Posture3DFloat.position', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rotation', full_name='rst.kinematics.Posture3DFloat.rotation', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.kinematics.Posture3DFloat.name', index=2,
      number=4, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=116,
  serialized_end=233,
)

_POSTURE3DFLOAT.fields_by_name['position'].message_type = rst.geometry.Translation_pb2._TRANSLATION
_POSTURE3DFLOAT.fields_by_name['rotation'].message_type = rst.geometry.Rotation_pb2._ROTATION
DESCRIPTOR.message_types_by_name['Posture3DFloat'] = _POSTURE3DFLOAT

class Posture3DFloat(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _POSTURE3DFLOAT

  # @@protoc_insertion_point(class_scope:rst.kinematics.Posture3DFloat)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\022Posture3DFloatType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/timing/Point2DTimestampPair.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.timing.Timestamp_pb2
import rst.math.Vec2DFloat_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/timing/Point2DTimestampPair.proto',
  package='rst.timing',
  serialized_pb='\n%rst/timing/Point2DTimestampPair.proto\x12\nrst.timing\x1a\x1arst/timing/Timestamp.proto\x1a\x19rst/math/Vec2DFloat.proto\"e\n\x14Point2DTimestampPair\x12#\n\x05point\x18\x01 \x02(\x0b\x32\x14.rst.math.Vec2DFloat\x12(\n\ttimestamp\x18\x02 \x02(\x0b\x32\x15.rst.timing.TimestampB\x1a\x42\x18Point2DTimestampPairType')




_POINT2DTIMESTAMPPAIR = _descriptor.Descriptor(
  name='Point2DTimestampPair',
  full_name='rst.timing.Point2DTimestampPair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='point', full_name='rst.timing.Point2DTimestampPair.point', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='rst.timing.Point2DTimestampPair.timestamp', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=108,
  serialized_end=209,
)

_POINT2DTIMESTAMPPAIR.fields_by_name['point'].message_type = rst.math.Vec2DFloat_pb2._VEC2DFLOAT
_POINT2DTIMESTAMPPAIR.fields_by_name['timestamp'].message_type = rst.timing.Timestamp_pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['Point2DTimestampPair'] = _POINT2DTIMESTAMPPAIR

class Point2DTimestampPair(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _POINT2DTIMESTAMPPAIR

  # @@protoc_insertion_point(class_scope:rst.timing.Point2DTimestampPair)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\030Point2DTimestampPairType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/kinematics/LinearVelocities.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/kinematics/LinearVelocities.proto',
  package='rst.kinematics',
  serialized_pb='\n%rst/kinematics/LinearVelocities.proto\x12\x0erst.kinematics\"3\n\x10LinearVelocities\x12\t\n\x01x\x18\x01 \x02(\x02\x12\t\n\x01y\x18\x02 \x02(\x02\x12\t\n\x01z\x18\x03 \x02(\x02\x42\x16\x42\x14LinearVelocitiesType')




_LINEARVELOCITIES = _descriptor.Descriptor(
  name='LinearVelocities',
  full_name='rst.kinematics.LinearVelocities',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='rst.kinematics.LinearVelocities.x', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='y', full_name='rst.kinematics.LinearVelocities.y', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='z', full_name='rst.kinematics.LinearVelocities.z', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=57,
  serialized_end=108,
)

DESCRIPTOR.message_types_by_name['LinearVelocities'] = _LINEARVELOCITIES

class LinearVelocities(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _LINEARVELOCITIES

  # @@protoc_insertion_point(class_scope:rst.kinematics.LinearVelocities)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\024LinearVelocitiesType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/calendar/RequestStatus.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/calendar/RequestStatus.proto',
  package='rst.calendar',
  serialized_pb='\n rst/calendar/RequestStatus.proto\x12\x0crst.calendar\"o\n\rRequestStatus\x12\x10\n\x08language\x18\x01 \x01(\t\x12\x13\n\x0bstatus_code\x18\x02 \x02(\t\x12\x1a\n\x12status_description\x18\x03 \x02(\t\x12\x1b\n\x13\x65xception_text_data\x18\x04 \x02(\tB\x13\x42\x11RequestStatusType')




_REQUESTSTATUS = _descriptor.Descriptor(
  name='RequestStatus',
  full_name='rst.calendar.RequestStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='language', full_name='rst.calendar.RequestStatus.language', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status_code', full_name='rst.calendar.RequestStatus.status_code', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status_description', full_name='rst.calendar.RequestStatus.status_description', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exception_text_data', full_name='rst.calendar.RequestStatus.exception_text_data', index=3,
      number=4, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=50,
  serialized_end=161,
)

DESCRIPTOR.message_types_by_name['RequestStatus'] = _REQUESTSTATUS

class RequestStatus(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _REQUESTSTATUS

  # @@protoc_insertion_point(class_scope:rst.calendar.RequestStatus)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\021RequestStatusType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/geometry/FieldOfView.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/geometry/FieldOfView.proto',
  package='rst.geometry',
  serialized_pb='\n\x1erst/geometry/FieldOfView.proto\x12\x0crst.geometry\";\n\x0b\x46ieldOfView\x12\x16\n\x0ehorizontal_aov\x18\x01 \x02(\x02\x12\x14\n\x0cvertical_aov\x18\x02 \x02(\x02\x42\x11\x42\x0f\x46ieldOfViewType')




_FIELDOFVIEW = _descriptor.Descriptor(
  name='FieldOfView',
  full_name='rst.geometry.FieldOfView',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='horizontal_aov', full_name='rst.geometry.FieldOfView.horizontal_aov', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='vertical_aov', full_name='rst.geometry.FieldOfView.vertical_aov', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=48,
  serialized_end=107,
)

DESCRIPTOR.message_types_by_name['FieldOfView'] = _FIELDOFVIEW

class FieldOfView(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _FIELDOFVIEW

  # @@protoc_insertion_point(class_scope:rst.geometry.FieldOfView)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\017FieldOfViewType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/motioncontrol/MotionStatus.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/motioncontrol/MotionStatus.proto',
  package='rst.motioncontrol',
  serialized_pb='\n$rst/motioncontrol/MotionStatus.proto\x12\x11rst.motioncontrol\"!\n\x0cMotionStatus\x12\x11\n\tconverged\x18\x01 \x02(\x08\x42\x12\x42\x10MotionStatusType')




_MOTIONSTATUS = _descriptor.Descriptor(
  name='MotionStatus',
  full_name='rst.motioncontrol.MotionStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='converged', full_name='rst.motioncontrol.MotionStatus.converged', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=59,
  serialized_end=92,
)

DESCRIPTOR.message_types_by_name['MotionStatus'] = _MOTIONSTATUS

class MotionStatus(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _MOTIONSTATUS

  # @@protoc_insertion_point(class_scope:rst.motioncontrol.MotionStatus)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\020MotionStatusType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/vision/AugmentedPointCloudSet3DFloat.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.vision.AugmentedPointCloud3DFloat_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/vision/AugmentedPointCloudSet3DFloat.proto',
  package='rst.vision',
  serialized_pb='\n.rst/vision/AugmentedPointCloudSet3DFloat.proto\x12\nrst.vision\x1a+rst/vision/AugmentedPointCloud3DFloat.proto\"W\n\x1d\x41ugmentedPointCloudSet3DFloat\x12\x36\n\x06\x63louds\x18\x01 \x03(\x0b\x32&.rst.vision.AugmentedPointCloud3DFloatB#B!AugmentedPointCloudSet3DFloatType')




_AUGMENTEDPOINTCLOUDSET3DFLOAT = _descriptor.Descriptor(
  name='AugmentedPointCloudSet3DFloat',
  full_name='rst.vision.AugmentedPointCloudSet3DFloat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='clouds', full_name='rst.vision.AugmentedPointCloudSet3DFloat.clouds', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=107,
  serialized_end=194,
)

_AUGMENTEDPOINTCLOUDSET3DFLOAT.fields_by_name['clouds'].message_type = rst.vision.AugmentedPointCloud3DFloat_pb2._AUGMENTEDPOINTCLOUD3DFLOAT
DESCRIPTOR.message_types_by_name['AugmentedPointCloudSet3DFloat'] = _AUGMENTEDPOINTCLOUDSET3DFLOAT

class AugmentedPointCloudSet3DFloat(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _AUGMENTEDPOINTCLOUDSET3DFLOAT

  # @@protoc_insertion_point(class_scope:rst.vision.AugmentedPointCloudSet3DFloat)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B!AugmentedPointCloudSet3DFloatType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/tracking/TrackedPose.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.tracking.TrackingInfo_pb2
import rst.geometry.Pose_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/tracking/TrackedPose.proto',
  package='rst.tracking',
  serialized_pb='\n\x1erst/tracking/TrackedPose.proto\x12\x0crst.tracking\x1a\x1frst/tracking/TrackingInfo.proto\x1a\x17rst/geometry/Pose.proto\"\x96\x01\n\x0bTrackedPose\x12(\n\x04info\x18\x01 \x02(\x0b\x32\x1a.rst.tracking.TrackingInfo\x12 \n\x04pose\x18\x02 \x02(\x0b\x32\x12.rst.geometry.Pose\x12\x1e\n\x16translation_confidence\x18\x03 \x01(\x02\x12\x1b\n\x13rotation_confidence\x18\x04 \x01(\x02\x42\x11\x42\x0fTrackedPoseType')




_TRACKEDPOSE = _descriptor.Descriptor(
  name='TrackedPose',
  full_name='rst.tracking.TrackedPose',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='info', full_name='rst.tracking.TrackedPose.info', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pose', full_name='rst.tracking.TrackedPose.pose', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='translation_confidence', full_name='rst.tracking.TrackedPose.translation_confidence', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rotation_confidence', full_name='rst.tracking.TrackedPose.rotation_confidence', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=107,
  serialized_end=257,
)

_TRACKEDPOSE.fields_by_name['info'].message_type = rst.tracking.TrackingInfo_pb2._TRACKINGINFO
_TRACKEDPOSE.fields_by_name['pose'].message_type = rst.geometry.Pose_pb2._POSE
DESCRIPTOR.message_types_by_name['TrackedPose'] = _TRACKEDPOSE

class TrackedPose(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TRACKEDPOSE

  # @@protoc_insertion_point(class_scope:rst.tracking.TrackedPose)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\017TrackedPoseType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/vision/Face.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.geometry.BoundingBox_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/vision/Face.proto',
  package='rst.vision',
  serialized_pb='\n\x15rst/vision/Face.proto\x12\nrst.vision\x1a\x1erst/geometry/BoundingBox.proto\"E\n\x04\x46\x61\x63\x65\x12)\n\x06region\x18\x01 \x02(\x0b\x32\x19.rst.geometry.BoundingBox\x12\x12\n\nconfidence\x18\x02 \x01(\x01\x42\nB\x08\x46\x61\x63\x65Type')




_FACE = _descriptor.Descriptor(
  name='Face',
  full_name='rst.vision.Face',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='region', full_name='rst.vision.Face.region', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='confidence', full_name='rst.vision.Face.confidence', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=69,
  serialized_end=138,
)

_FACE.fields_by_name['region'].message_type = rst.geometry.BoundingBox_pb2._BOUNDINGBOX
DESCRIPTOR.message_types_by_name['Face'] = _FACE

class Face(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _FACE

  # @@protoc_insertion_point(class_scope:rst.vision.Face)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\010FaceType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/kinematics/Twist.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.kinematics.LinearVelocities_pb2
import rst.kinematics.AngularVelocities_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/kinematics/Twist.proto',
  package='rst.kinematics',
  serialized_pb='\n\x1arst/kinematics/Twist.proto\x12\x0erst.kinematics\x1a%rst/kinematics/LinearVelocities.proto\x1a&rst/kinematics/AngularVelocities.proto\"m\n\x05Twist\x12\x30\n\x06linear\x18\x01 \x02(\x0b\x32 .rst.kinematics.LinearVelocities\x12\x32\n\x07\x61ngular\x18\x02 \x02(\x0b\x32!.rst.kinematics.AngularVelocitiesB\x0b\x42\tTwistType')




_TWIST = _descriptor.Descriptor(
  name='Twist',
  full_name='rst.kinematics.Twist',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='linear', full_name='rst.kinematics.Twist.linear', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='angular', full_name='rst.kinematics.Twist.angular', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=125,
  serialized_end=234,
)

_TWIST.fields_by_name['linear'].message_type = rst.kinematics.LinearVelocities_pb2._LINEARVELOCITIES
_TWIST.fields_by_name['angular'].message_type = rst.kinematics.AngularVelocities_pb2._ANGULARVELOCITIES
DESCRIPTOR.message_types_by_name['Twist'] = _TWIST

class Twist(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TWIST

  # @@protoc_insertion_point(class_scope:rst.kinematics.Twist)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\tTwistType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/dynamics/Forces.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/dynamics/Forces.proto',
  package='rst.dynamics',
  serialized_pb='\n\x19rst/dynamics/Forces.proto\x12\x0crst.dynamics\")\n\x06\x46orces\x12\t\n\x01x\x18\x01 \x02(\x02\x12\t\n\x01y\x18\x02 \x02(\x02\x12\t\n\x01z\x18\x03 \x02(\x02\x42\x0c\x42\nForcesType')




_FORCES = _descriptor.Descriptor(
  name='Forces',
  full_name='rst.dynamics.Forces',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='rst.dynamics.Forces.x', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='y', full_name='rst.dynamics.Forces.y', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='z', full_name='rst.dynamics.Forces.z', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=43,
  serialized_end=84,
)

DESCRIPTOR.message_types_by_name['Forces'] = _FORCES

class Forces(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _FORCES

  # @@protoc_insertion_point(class_scope:rst.dynamics.Forces)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\nForcesType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/classification/ClassifiedRegions2D.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.classification.ClassifiedRegion2D_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/classification/ClassifiedRegions2D.proto',
  package='rst.classification',
  serialized_pb='\n,rst/classification/ClassifiedRegions2D.proto\x12\x12rst.classification\x1a+rst/classification/ClassifiedRegion2D.proto\"N\n\x13\x43lassifiedRegions2D\x12\x37\n\x07regions\x18\x01 \x03(\x0b\x32&.rst.classification.ClassifiedRegion2DB\x19\x42\x17\x43lassifiedRegions2DType')




_CLASSIFIEDREGIONS2D = _descriptor.Descriptor(
  name='ClassifiedRegions2D',
  full_name='rst.classification.ClassifiedRegions2D',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='regions', full_name='rst.classification.ClassifiedRegions2D.regions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=113,
  serialized_end=191,
)

_CLASSIFIEDREGIONS2D.fields_by_name['regions'].message_type = rst.classification.ClassifiedRegion2D_pb2._CLASSIFIEDREGION2D
DESCRIPTOR.message_types_by_name['ClassifiedRegions2D'] = _CLASSIFIEDREGIONS2D

class ClassifiedRegions2D(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _CLASSIFIEDREGIONS2D

  # @@protoc_insertion_point(class_scope:rst.classification.ClassifiedRegions2D)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\027ClassifiedRegions2DType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/generic/DictionaryCollection.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.generic.Dictionary_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/generic/DictionaryCollection.proto',
  package='rst.generic',
  serialized_pb='\n&rst/generic/DictionaryCollection.proto\x12\x0brst.generic\x1a\x1crst/generic/Dictionary.proto\"@\n\x14\x44ictionaryCollection\x12(\n\x07\x65lement\x18\x01 \x03(\x0b\x32\x17.rst.generic.DictionaryB\x1a\x42\x18\x44ictionaryCollectionType')




_DICTIONARYCOLLECTION = _descriptor.Descriptor(
  name='DictionaryCollection',
  full_name='rst.generic.DictionaryCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='element', full_name='rst.generic.DictionaryCollection.element', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=85,
  serialized_end=149,
)

_DICTIONARYCOLLECTION.fields_by_name['element'].message_type = rst.generic.Dictionary_pb2._DICTIONARY
DESCRIPTOR.message_types_by_name['DictionaryCollection'] = _DICTIONARYCOLLECTION

class DictionaryCollection(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _DICTIONARYCOLLECTION

  # @@protoc_insertion_point(class_scope:rst.generic.DictionaryCollection)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\030DictionaryCollectionType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/tracking/States.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.tracking.State_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/tracking/States.proto',
  package='rst.tracking',
  serialized_pb='\n\x19rst/tracking/States.proto\x12\x0crst.tracking\x1a\x18rst/tracking/State.proto\",\n\x06States\x12\"\n\x05state\x18\x01 \x03(\x0b\x32\x13.rst.tracking.StateB\x0c\x42\nStatesType')




_STATES = _descriptor.Descriptor(
  name='States',
  full_name='rst.tracking.States',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='rst.tracking.States.state', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=69,
  serialized_end=113,
)

_STATES.fields_by_name['state'].message_type = rst.tracking.State_pb2._STATE
DESCRIPTOR.message_types_by_name['States'] = _STATES

class States(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _STATES

  # @@protoc_insertion_point(class_scope:rst.tracking.States)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\nStatesType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/vision/Images.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.vision.Image_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/vision/Images.proto',
  package='rst.vision',
  serialized_pb='\n\x17rst/vision/Images.proto\x12\nrst.vision\x1a\x16rst/vision/Image.proto\"+\n\x06Images\x12!\n\x06images\x18\x01 \x03(\x0b\x32\x11.rst.vision.ImageB\x0c\x42\nImagesType')




_IMAGES = _descriptor.Descriptor(
  name='Images',
  full_name='rst.vision.Images',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='images', full_name='rst.vision.Images.images', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=63,
  serialized_end=106,
)

_IMAGES.fields_by_name['images'].message_type = rst.vision.Image_pb2._IMAGE
DESCRIPTOR.message_types_by_name['Images'] = _IMAGES

class Images(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _IMAGES

  # @@protoc_insertion_point(class_scope:rst.vision.Images)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\nImagesType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/graph/Edge.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.generic.Value_pb2
import rst.generic.Dictionary_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/graph/Edge.proto',
  package='rst.graph',
  serialized_pb='\n\x14rst/graph/Edge.proto\x12\trst.graph\x1a\x17rst/generic/Value.proto\x1a\x1crst/generic/Dictionary.proto\"q\n\x04\x45\x64ge\x12\x0c\n\x04head\x18\x01 \x02(\r\x12\x0c\n\x04tail\x18\x02 \x02(\r\x12 \n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x12.rst.generic.Value\x12+\n\nproperties\x18\x04 \x01(\x0b\x32\x17.rst.generic.DictionaryB\nB\x08\x45\x64geType')




_EDGE = _descriptor.Descriptor(
  name='Edge',
  full_name='rst.graph.Edge',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='head', full_name='rst.graph.Edge.head', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tail', full_name='rst.graph.Edge.tail', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data', full_name='rst.graph.Edge.data', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='properties', full_name='rst.graph.Edge.properties', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=90,
  serialized_end=203,
)

_EDGE.fields_by_name['data'].message_type = rst.generic.Value_pb2._VALUE
_EDGE.fields_by_name['properties'].message_type = rst.generic.Dictionary_pb2._DICTIONARY
DESCRIPTOR.message_types_by_name['Edge'] = _EDGE

class Edge(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _EDGE

  # @@protoc_insertion_point(class_scope:rst.graph.Edge)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\010EdgeType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/math/Vec2DInt.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/math/Vec2DInt.proto',
  package='rst.math',
  serialized_pb='\n\x17rst/math/Vec2DInt.proto\x12\x08rst.math\"&\n\x08Vec2DInt\x12\x0c\n\x01x\x18\x01 \x02(\x05:\x01\x30\x12\x0c\n\x01y\x18\x02 \x02(\x05:\x01\x30\x42\x0e\x42\x0cVec2DIntType')




_VEC2DINT = _descriptor.Descriptor(
  name='Vec2DInt',
  full_name='rst.math.Vec2DInt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='rst.math.Vec2DInt.x', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='y', full_name='rst.math.Vec2DInt.y', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=37,
  serialized_end=75,
)

DESCRIPTOR.message_types_by_name['Vec2DInt'] = _VEC2DINT

class Vec2DInt(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _VEC2DINT

  # @@protoc_insertion_point(class_scope:rst.math.Vec2DInt)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\014Vec2DIntType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/geometry/ViewFrustumCollection.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.geometry.ViewFrustum_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/geometry/ViewFrustumCollection.proto',
  package='rst.geometry',
  serialized_pb='\n(rst/geometry/ViewFrustumCollection.proto\x12\x0crst.geometry\x1a\x1erst/geometry/ViewFrustum.proto\"C\n\x15ViewFrustumCollection\x12*\n\x07\x65lement\x18\x01 \x03(\x0b\x32\x19.rst.geometry.ViewFrustumB\x1b\x42\x19ViewFrustumCollectionType')




_VIEWFRUSTUMCOLLECTION = _descriptor.Descriptor(
  name='ViewFrustumCollection',
  full_name='rst.geometry.ViewFrustumCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='element', full_name='rst.geometry.ViewFrustumCollection.element', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=90,
  serialized_end=157,
)

_VIEWFRUSTUMCOLLECTION.fields_by_name['element'].message_type = rst.geometry.ViewFrustum_pb2._VIEWFRUSTUM
DESCRIPTOR.message_types_by_name['ViewFrustumCollection'] = _VIEWFRUSTUMCOLLECTION

class ViewFrustumCollection(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _VIEWFRUSTUMCOLLECTION

  # @@protoc_insertion_point(class_scope:rst.geometry.ViewFrustumCollection)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\031ViewFrustumCollectionType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/stochastics/Gaussian1D.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/stochastics/Gaussian1D.proto',
  package='rst.stochastics',
  serialized_pb='\n rst/stochastics/Gaussian1D.proto\x12\x0frst.stochastics\",\n\nGaussian1D\x12\x0c\n\x04mean\x18\x01 \x02(\x02\x12\x10\n\x08variance\x18\x02 \x02(\x02\x42\x10\x42\x0eGaussian1DType')




_GAUSSIAN1D = _descriptor.Descriptor(
  name='Gaussian1D',
  full_name='rst.stochastics.Gaussian1D',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mean', full_name='rst.stochastics.Gaussian1D.mean', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='variance', full_name='rst.stochastics.Gaussian1D.variance', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=53,
  serialized_end=97,
)

DESCRIPTOR.message_types_by_name['Gaussian1D'] = _GAUSSIAN1D

class Gaussian1D(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _GAUSSIAN1D

  # @@protoc_insertion_point(class_scope:rst.stochastics.Gaussian1D)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\016Gaussian1DType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/dynamics/MotorCurrents.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/dynamics/MotorCurrents.proto',
  package='rst.dynamics',
  serialized_pb='\n rst/dynamics/MotorCurrents.proto\x12\x0crst.dynamics\"%\n\rMotorCurrents\x12\x14\n\x08\x63urrents\x18\x01 \x03(\x02\x42\x02\x10\x01\x42\x13\x42\x11MotorCurrentsType')




_MOTORCURRENTS = _descriptor.Descriptor(
  name='MotorCurrents',
  full_name='rst.dynamics.MotorCurrents',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='currents', full_name='rst.dynamics.MotorCurrents.currents', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), '\020\001')),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=50,
  serialized_end=87,
)

DESCRIPTOR.message_types_by_name['MotorCurrents'] = _MOTORCURRENTS

class MotorCurrents(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _MOTORCURRENTS

  # @@protoc_insertion_point(class_scope:rst.dynamics.MotorCurrents)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\021MotorCurrentsType')
_MOTORCURRENTS.fields_by_name['currents'].has_options = True
_MOTORCURRENTS.fields_by_name['currents']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), '\020\001')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/geometry/PolygonalPatch3D.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.geometry.Pose_pb2
import rst.math.Vec2DFloat_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/geometry/PolygonalPatch3D.proto',
  package='rst.geometry',
  serialized_pb='\n#rst/geometry/PolygonalPatch3D.proto\x12\x0crst.geometry\x1a\x17rst/geometry/Pose.proto\x1a\x19rst/math/Vec2DFloat.proto\"Z\n\x10PolygonalPatch3D\x12 \n\x04\x62\x61se\x18\x01 \x02(\x0b\x32\x12.rst.geometry.Pose\x12$\n\x06\x62order\x18\x02 \x03(\x0b\x32\x14.rst.math.Vec2DFloatB\x16\x42\x14PolygonalPatch3DType')




_POLYGONALPATCH3D = _descriptor.Descriptor(
  name='PolygonalPatch3D',
  full_name='rst.geometry.PolygonalPatch3D',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='rst.geometry.PolygonalPatch3D.base', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='border', full_name='rst.geometry.PolygonalPatch3D.border', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=105,
  serialized_end=195,
)

_POLYGONALPATCH3D.fields_by_name['base'].message_type = rst.geometry.Pose_pb2._POSE
_POLYGONALPATCH3D.fields_by_name['border'].message_type = rst.math.Vec2DFloat_pb2._VEC2DFLOAT
DESCRIPTOR.message_types_by_name['PolygonalPatch3D'] = _POLYGONALPATCH3D

class PolygonalPatch3D(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _POLYGONALPATCH3D

  # @@protoc_insertion_point(class_scope:rst.geometry.PolygonalPatch3D)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\024PolygonalPatch3DType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/hri/Body.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.geometry.Translation_pb2
import rst.geometry.Rotation_pb2
import rst.geometry.BoundingBox3DFloat_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/hri/Body.proto',
  package='rst.hri',
  serialized_pb='\n\x12rst/hri/Body.proto\x12\x07rst.hri\x1a\x1erst/geometry/Translation.proto\x1a\x1brst/geometry/Rotation.proto\x1a%rst/geometry/BoundingBox3DFloat.proto\"\x91\x01\n\x04\x42ody\x12+\n\x08location\x18\n \x01(\x0b\x32\x19.rst.geometry.Translation\x12+\n\x0borientation\x18\x14 \x01(\x0b\x32\x16.rst.geometry.Rotation\x12/\n\x05shape\x18\x1e \x01(\x0b\x32 .rst.geometry.BoundingBox3DFloatB\nB\x08\x42odyType')




_BODY = _descriptor.Descriptor(
  name='Body',
  full_name='rst.hri.Body',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='location', full_name='rst.hri.Body.location', index=0,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='orientation', full_name='rst.hri.Body.orientation', index=1,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='shape', full_name='rst.hri.Body.shape', index=2,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=132,
  serialized_end=277,
)

_BODY.fields_by_name['location'].message_type = rst.geometry.Translation_pb2._TRANSLATION
_BODY.fields_by_name['orientation'].message_type = rst.geometry.Rotation_pb2._ROTATION
_BODY.fields_by_name['shape'].message_type = rst.geometry.BoundingBox3DFloat_pb2._BOUNDINGBOX3DFLOAT
DESCRIPTOR.message_types_by_name['Body'] = _BODY

class Body(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _BODY

  # @@protoc_insertion_point(class_scope:rst.hri.Body)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\010BodyType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/generic/KeyValuePair.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.generic.Value_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/generic/KeyValuePair.proto',
  package='rst.generic',
  serialized_pb='\n\x1erst/generic/KeyValuePair.proto\x12\x0brst.generic\x1a\x17rst/generic/Value.proto\">\n\x0cKeyValuePair\x12\x0b\n\x03key\x18\x01 \x02(\t\x12!\n\x05value\x18\x02 \x02(\x0b\x32\x12.rst.generic.ValueB\x12\x42\x10KeyValuePairType')




_KEYVALUEPAIR = _descriptor.Descriptor(
  name='KeyValuePair',
  full_name='rst.generic.KeyValuePair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='rst.generic.KeyValuePair.key', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='rst.generic.KeyValuePair.value', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=72,
  serialized_end=134,
)

_KEYVALUEPAIR.fields_by_name['value'].message_type = rst.generic.Value_pb2._VALUE
DESCRIPTOR.message_types_by_name['KeyValuePair'] = _KEYVALUEPAIR

class KeyValuePair(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _KEYVALUEPAIR

  # @@protoc_insertion_point(class_scope:rst.generic.KeyValuePair)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\020KeyValuePairType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/tracking/TrackedPolygonalPatches3D.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.tracking.TrackedPolygonalPatch3D_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/tracking/TrackedPolygonalPatches3D.proto',
  package='rst.tracking',
  serialized_pb='\n,rst/tracking/TrackedPolygonalPatches3D.proto\x12\x0crst.tracking\x1a*rst/tracking/TrackedPolygonalPatch3D.proto\"Q\n\x19TrackedPolygonalPatches3D\x12\x34\n\x05patch\x18\x01 \x03(\x0b\x32%.rst.tracking.TrackedPolygonalPatch3DB\x1f\x42\x1dTrackedPolygonalPatches3DType')




_TRACKEDPOLYGONALPATCHES3D = _descriptor.Descriptor(
  name='TrackedPolygonalPatches3D',
  full_name='rst.tracking.TrackedPolygonalPatches3D',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='patch', full_name='rst.tracking.TrackedPolygonalPatches3D.patch', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=106,
  serialized_end=187,
)

_TRACKEDPOLYGONALPATCHES3D.fields_by_name['patch'].message_type = rst.tracking.TrackedPolygonalPatch3D_pb2._TRACKEDPOLYGONALPATCH3D
DESCRIPTOR.message_types_by_name['TrackedPolygonalPatches3D'] = _TRACKEDPOLYGONALPATCHES3D

class TrackedPolygonalPatches3D(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TRACKEDPOLYGONALPATCHES3D

  # @@protoc_insertion_point(class_scope:rst.tracking.TrackedPolygonalPatches3D)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\035TrackedPolygonalPatches3DType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/robot/PickAndPlaceAction.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.geometry.Pose_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/robot/PickAndPlaceAction.proto',
  package='rst.robot',
  serialized_pb='\n\"rst/robot/PickAndPlaceAction.proto\x12\trst.robot\x1a\x17rst/geometry/Pose.proto\"a\n\x12PickAndPlaceAction\x12$\n\x08pickPose\x18\x01 \x02(\x0b\x32\x12.rst.geometry.Pose\x12%\n\tplacePose\x18\x02 \x02(\x0b\x32\x12.rst.geometry.PoseB\x18\x42\x16PickAndPlaceActionType')




_PICKANDPLACEACTION = _descriptor.Descriptor(
  name='PickAndPlaceAction',
  full_name='rst.robot.PickAndPlaceAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pickPose', full_name='rst.robot.PickAndPlaceAction.pickPose', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='placePose', full_name='rst.robot.PickAndPlaceAction.placePose', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=74,
  serialized_end=171,
)

_PICKANDPLACEACTION.fields_by_name['pickPose'].message_type = rst.geometry.Pose_pb2._POSE
_PICKANDPLACEACTION.fields_by_name['placePose'].message_type = rst.geometry.Pose_pb2._POSE
DESCRIPTOR.message_types_by_name['PickAndPlaceAction'] = _PICKANDPLACEACTION

class PickAndPlaceAction(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _PICKANDPLACEACTION

  # @@protoc_insertion_point(class_scope:rst.robot.PickAndPlaceAction)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\026PickAndPlaceActionType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/kinematics/CollisionGeometry.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.geometry.Translation_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/kinematics/CollisionGeometry.proto',
  package='rst.kinematics',
  serialized_pb='\n&rst/kinematics/CollisionGeometry.proto\x12\x0erst.kinematics\x1a\x1erst/geometry/Translation.proto\"F\n\x11\x43ollisionGeometry\x12\x31\n\x0e\x63ontact_points\x18\x01 \x03(\x0b\x32\x19.rst.geometry.TranslationB\x17\x42\x15\x43ollisionGeometryType')




_COLLISIONGEOMETRY = _descriptor.Descriptor(
  name='CollisionGeometry',
  full_name='rst.kinematics.CollisionGeometry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='contact_points', full_name='rst.kinematics.CollisionGeometry.contact_points', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=90,
  serialized_end=160,
)

_COLLISIONGEOMETRY.fields_by_name['contact_points'].message_type = rst.geometry.Translation_pb2._TRANSLATION
DESCRIPTOR.message_types_by_name['CollisionGeometry'] = _COLLISIONGEOMETRY

class CollisionGeometry(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _COLLISIONGEOMETRY

  # @@protoc_insertion_point(class_scope:rst.kinematics.CollisionGeometry)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\025CollisionGeometryType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/dialog/DialogActCollection.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.dialog.DialogAct_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/dialog/DialogActCollection.proto',
  package='rst.dialog',
  serialized_pb='\n$rst/dialog/DialogActCollection.proto\x12\nrst.dialog\x1a\x1arst/dialog/DialogAct.proto\"=\n\x13\x44ialogActCollection\x12&\n\x07\x65lement\x18\x01 \x03(\x0b\x32\x15.rst.dialog.DialogActB\x19\x42\x17\x44ialogActCollectionType')




_DIALOGACTCOLLECTION = _descriptor.Descriptor(
  name='DialogActCollection',
  full_name='rst.dialog.DialogActCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='element', full_name='rst.dialog.DialogActCollection.element', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=80,
  serialized_end=141,
)

_DIALOGACTCOLLECTION.fields_by_name['element'].message_type = rst.dialog.DialogAct_pb2._DIALOGACT
DESCRIPTOR.message_types_by_name['DialogActCollection'] = _DIALOGACTCOLLECTION

class DialogActCollection(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _DIALOGACTCOLLECTION

  # @@protoc_insertion_point(class_scope:rst.dialog.DialogActCollection)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\027DialogActCollectionType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/dynamics/Wrench.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.dynamics.Forces_pb2
import rst.dynamics.Torques_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/dynamics/Wrench.proto',
  package='rst.dynamics',
  serialized_pb='\n\x19rst/dynamics/Wrench.proto\x12\x0crst.dynamics\x1a\x19rst/dynamics/Forces.proto\x1a\x1arst/dynamics/Torques.proto\"V\n\x06Wrench\x12$\n\x06\x66orces\x18\x01 \x02(\x0b\x32\x14.rst.dynamics.Forces\x12&\n\x07torques\x18\x02 \x02(\x0b\x32\x15.rst.dynamics.TorquesB\x0c\x42\nWrenchType')




_WRENCH = _descriptor.Descriptor(
  name='Wrench',
  full_name='rst.dynamics.Wrench',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='forces', full_name='rst.dynamics.Wrench.forces', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='torques', full_name='rst.dynamics.Wrench.torques', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=98,
  serialized_end=184,
)

_WRENCH.fields_by_name['forces'].message_type = rst.dynamics.Forces_pb2._FORCES
_WRENCH.fields_by_name['torques'].message_type = rst.dynamics.Torques_pb2._TORQUES
DESCRIPTOR.message_types_by_name['Wrench'] = _WRENCH

class Wrench(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _WRENCH

  # @@protoc_insertion_point(class_scope:rst.dynamics.Wrench)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\nWrenchType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/audition/SoundChunkCollection.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.audition.SoundChunk_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/audition/SoundChunkCollection.proto',
  package='rst.audition',
  serialized_pb='\n\'rst/audition/SoundChunkCollection.proto\x12\x0crst.audition\x1a\x1drst/audition/SoundChunk.proto\"A\n\x14SoundChunkCollection\x12)\n\x07\x65lement\x18\x01 \x03(\x0b\x32\x18.rst.audition.SoundChunkB\x1a\x42\x18SoundChunkCollectionType')




_SOUNDCHUNKCOLLECTION = _descriptor.Descriptor(
  name='SoundChunkCollection',
  full_name='rst.audition.SoundChunkCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='element', full_name='rst.audition.SoundChunkCollection.element', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=88,
  serialized_end=153,
)

_SOUNDCHUNKCOLLECTION.fields_by_name['element'].message_type = rst.audition.SoundChunk_pb2._SOUNDCHUNK
DESCRIPTOR.message_types_by_name['SoundChunkCollection'] = _SOUNDCHUNKCOLLECTION

class SoundChunkCollection(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _SOUNDCHUNKCOLLECTION

  # @@protoc_insertion_point(class_scope:rst.audition.SoundChunkCollection)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\030SoundChunkCollectionType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/geometry/AxisAlignedBoundingBox3DFloat.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.geometry.Translation_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/geometry/AxisAlignedBoundingBox3DFloat.proto',
  package='rst.geometry',
  serialized_pb='\n0rst/geometry/AxisAlignedBoundingBox3DFloat.proto\x12\x0crst.geometry\x1a\x1erst/geometry/Translation.proto\"\x83\x01\n\x1d\x41xisAlignedBoundingBox3DFloat\x12\x34\n\x11left_front_bottom\x18\x01 \x02(\x0b\x32\x19.rst.geometry.Translation\x12\r\n\x05width\x18\x02 \x02(\x02\x12\r\n\x05\x64\x65pth\x18\x03 \x02(\x02\x12\x0e\n\x06height\x18\x04 \x02(\x02\x42#B!AxisAlignedBoundingBox3DFloatType')




_AXISALIGNEDBOUNDINGBOX3DFLOAT = _descriptor.Descriptor(
  name='AxisAlignedBoundingBox3DFloat',
  full_name='rst.geometry.AxisAlignedBoundingBox3DFloat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='left_front_bottom', full_name='rst.geometry.AxisAlignedBoundingBox3DFloat.left_front_bottom', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='width', full_name='rst.geometry.AxisAlignedBoundingBox3DFloat.width', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='depth', full_name='rst.geometry.AxisAlignedBoundingBox3DFloat.depth', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='height', full_name='rst.geometry.AxisAlignedBoundingBox3DFloat.height', index=3,
      number=4, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=99,
  serialized_end=230,
)

_AXISALIGNEDBOUNDINGBOX3DFLOAT.fields_by_name['left_front_bottom'].message_type = rst.geometry.Translation_pb2._TRANSLATION
DESCRIPTOR.message_types_by_name['AxisAlignedBoundingBox3DFloat'] = _AXISALIGNEDBOUNDINGBOX3DFLOAT

class AxisAlignedBoundingBox3DFloat(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _AXISALIGNEDBOUNDINGBOX3DFLOAT

  # @@protoc_insertion_point(class_scope:rst.geometry.AxisAlignedBoundingBox3DFloat)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B!AxisAlignedBoundingBox3DFloatType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/geometry/Translation.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/geometry/Translation.proto',
  package='rst.geometry',
  serialized_pb='\n\x1erst/geometry/Translation.proto\x12\x0crst.geometry\"@\n\x0bTranslation\x12\t\n\x01x\x18\x01 \x02(\x01\x12\t\n\x01y\x18\x02 \x02(\x01\x12\t\n\x01z\x18\x03 \x02(\x01\x12\x10\n\x08\x66rame_id\x18\x08 \x01(\tB\x11\x42\x0fTranslationType')




_TRANSLATION = _descriptor.Descriptor(
  name='Translation',
  full_name='rst.geometry.Translation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='rst.geometry.Translation.x', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='y', full_name='rst.geometry.Translation.y', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='z', full_name='rst.geometry.Translation.z', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='frame_id', full_name='rst.geometry.Translation.frame_id', index=3,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=48,
  serialized_end=112,
)

DESCRIPTOR.message_types_by_name['Translation'] = _TRANSLATION

class Translation(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TRANSLATION

  # @@protoc_insertion_point(class_scope:rst.geometry.Translation)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\017TranslationType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/tracking/TrackingInfo.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/tracking/TrackingInfo.proto',
  package='rst.tracking',
  serialized_pb='\n\x1frst/tracking/TrackingInfo.proto\x12\x0crst.tracking\"1\n\x0cTrackingInfo\x12\n\n\x02id\x18\x01 \x02(\r\x12\x15\n\rpersistent_id\x18\x02 \x01(\x0c\x42\x12\x42\x10TrackingInfoType')




_TRACKINGINFO = _descriptor.Descriptor(
  name='TrackingInfo',
  full_name='rst.tracking.TrackingInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='rst.tracking.TrackingInfo.id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='persistent_id', full_name='rst.tracking.TrackingInfo.persistent_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value="",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=49,
  serialized_end=98,
)

DESCRIPTOR.message_types_by_name['TrackingInfo'] = _TRACKINGINFO

class TrackingInfo(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TRACKINGINFO

  # @@protoc_insertion_point(class_scope:rst.tracking.TrackingInfo)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\020TrackingInfoType')
# @@protoc_insertion_point(module_scope)
